@@ -1,6 +1,6 @@
 import pickle
 from pathlib import Path
-from typing import Any, List, Tuple
+from typing import Any
 
 import numpy as np
 import pandas as pd
@@ -15,7 +15,12 @@ from rexify.features.pipelines import (
     NumericalPipeline,
     RankingPipeline,
 )
-from rexify.utils import get_target_id, make_dirs
+from rexify.utils import (
+    get_ranking_features,
+    get_schema_features,
+    get_target_id,
+    make_dirs,
+)
 
 
 class FeatureExtractor(BaseEstimator, TransformerMixin, TfDatasetGenerator):
@@ -28,10 +33,6 @@ class FeatureExtractor(BaseEstimator, TransformerMixin, TfDatasetGenerator):
     transformer will infer a `sklearn.pipeline.Pipeline` and its steps
     to fit and transform the data, according to the passed schema.
 
-    Args:
-        schema (dict): a dictionary of dictionaries, corresponding to
-            the user, item and context features
-
     Examples:
 
         >>> from rexify.features import FeatureExtractor
@@ -55,9 +56,7 @@ class FeatureExtractor(BaseEstimator, TransformerMixin, TfDatasetGenerator):
     _ppl: ColumnTransformer
     _model_params: dict[str, Any]
     _output_features: list[str]
-
-    def __init__(self, schema: dict[str, dict[str, str]]):
-        super(FeatureExtractor, self).__init__(schema=schema)
+    _rating_add: bool
 
     def fit(self, X: pd.DataFrame, *_):
         """Fit FeatureExtractor to X.
@@ -69,7 +68,10 @@ class FeatureExtractor(BaseEstimator, TransformerMixin, TfDatasetGenerator):
             self: fitted encoder
         """
         self._ppl = self._make_transformer()
-        self._ppl.fit(X)
+        self._check_rating_col(X)
+        self._validate_input(X)
+        x_ = self._add_rating_col(X)
+        self._ppl.fit(x_)
         self._model_params = self._get_model_params(X)
         return self
 
@@ -84,7 +86,8 @@ class FeatureExtractor(BaseEstimator, TransformerMixin, TfDatasetGenerator):
             numpy.ndarray: an array with the preprocessed features
 
         """
-        return self._ppl.transform(X)
+        x = self._add_rating_col(X)
+        return self._ppl.transform(x)
 
     def save(self, output_dir: str):
         make_dirs(output_dir)
@@ -134,11 +137,12 @@ class FeatureExtractor(BaseEstimator, TransformerMixin, TfDatasetGenerator):
             "item_id": item_id,
             "user_dims": user_input_dim,
             "user_id": user_id,
+            "ranking_features": X["event_type"].unique().tolist(),
         }
 
     def _get_features_transformers(
         self, target: str
-    ) -> List[Tuple[str, Pipeline, List[str]]]:
+    ) -> list[tuple[str, Pipeline, list[str]]]:
         transformer_list = []
 
         if target != "rank":
@@ -154,3 +158,26 @@ class FeatureExtractor(BaseEstimator, TransformerMixin, TfDatasetGenerator):
             transformer_list.append(RankingPipeline(self.schema, target))
 
         return transformer_list
+
+    def _validate_input(
+        self,
+        X: pd.DataFrame,
+    ):
+        schema_columns = get_schema_features(self.schema)
+        columns = ["event_type"] + schema_columns
+        assert all([col in X.columns for col in columns])
+
+        ranking_features = get_ranking_features(self.schema)
+        assert all(
+            [feat in X["event_type"].unique().tolist() for feat in ranking_features]
+        )
+
+    def _check_rating_col(self, X: pd.DataFrame):
+        if "rating" not in X.columns:
+            self._rating_add = True
+
+    def _add_rating_col(self, X: pd.DataFrame) -> pd.DataFrame:
+        x_ = X.copy()
+        if self._rating_add:
+            x_["rating"] = np.zeros(X.shape[0])
+        return x_
